@@ -79,7 +79,11 @@ static void bg_file_track_id(bg_tree_t *tree FFUNUSED, int *id FFUNUSED)
 #endif // ]
 
 static bg_tree_vmt_t bg_file_vmt={
+#if defined (PBU_MESSAGE_AV_LOG) // [
+  .id="file",
+#else // ] [
   .id=FFL("file"),
+#endif // ]
   .type=BG_TREE_TYPE_FILE,
   .destroy=bg_file_destroy,
   .accept=bg_file_accept,
