@@ -232,18 +232,22 @@ e_annotate:
 }
 
 #if defined (BG_PARAM_THREADS) // [
+//#define BG_MUXER_PARENT
 static int bg_muxer_track(bg_tree_t *tree, bg_visitor_t *vis)
 {
   int err=-1;
   bg_track_t *track=&tree->track;
+#if defined (BG_MUXER_PARENT) // [
   bg_tree_t *parent=tree->parent;
+#endif // ]
   bg_param_t *param=tree->param;
   int apply=BG_FLAGS_MODE_APPLY&param->flags.mode;
 #if defined (FF_FLAC_HACK) // [
   int hack;
   AVCodecParameters *codecpar;
-  enum AVSampleFormat sample_fmt;
+  //enum AVSampleFormat sample_fmt;
 #endif // ]
+  enum AVSampleFormat sample_fmt;
   ff_inout_t output;
   double gain_track,gain_album,gain,volume;
   char filter[128];
@@ -259,6 +263,7 @@ static int bg_muxer_track(bg_tree_t *tree, bg_visitor_t *vis)
     _DMESSAGE("re-opening input");
     goto e_input;
   }
+//fprintf(stderr,"(%s,%d,%s) %d\n",pbu_basename(__FILE__),__LINE__,__func__,hack);fflush(stderr);exit(1);
 #else // ] [
   if (ff_input_open_muxer(&track->input)<0) {
     _DMESSAGE("re-opening input");
@@ -298,14 +303,19 @@ static int bg_muxer_track(bg_tree_t *tree, bg_visitor_t *vis)
 #endif // ]
 
 //_DWRITELNV("\"%s\"",tree->source.path);
+//#if defined (_WIN32) // [
+//fprintf(stderr,"\"%S\"\n",tree->source.path); fflush(stderr);
+//#endif // ]
   /////////////////////////////////////////////////////////////////////////////
 #if defined (FF_FLAC_HACK) // [
+  codecpar=track->input.fmt.ctx->streams[track->input.ai]->codecpar;
+  sample_fmt=hack?codecpar->format:AV_SAMPLE_FMT_NONE;
   // as it seems it is impossible to pass through a partial flac stream
   // (cf. "https://trac.ffmpeg.org/ticket/7864".) our hack consists in
   // reading/decoding and re-encoding/writing./ hence we've need to tell
   // the output the format from decoding.
-  codecpar=track->input.fmt.ctx->streams[track->input.ai]->codecpar;
-  sample_fmt=hack?codecpar->format:AV_SAMPLE_FMT_NONE;
+  //codecpar=track->input.fmt.ctx->streams[track->input.ai]->codecpar;
+  //sample_fmt=hack?codecpar->format:AV_SAMPLE_FMT_NONE;
 #if defined (FF_INPUT_LIST) // [
   err=ff_output_create(&output,&bg_output_callback,tree,sample_fmt,
       param->process&&param->list.out);
@@ -318,9 +328,10 @@ static int bg_muxer_track(bg_tree_t *tree, bg_visitor_t *vis)
     goto e_output;
   }
 #else // ] [
-  if (ff_output_streams_create(&output)<0) {
+  sample_fmt=AV_SAMPLE_FMT_NONE;
+	if (ff_output_create(&output,&bg_output_callback,tree,sample_fmt)<0) {
     _DMESSAGE("creating output streams");
-    goto e_output_streams;
+    goto e_output;
   }
 #endif // ]
 
@@ -332,23 +343,41 @@ static int bg_muxer_track(bg_tree_t *tree, bg_visitor_t *vis)
 
   if (apply) {
     if (param->weight.enabled) {
+#if defined (BG_MUXER_PARENT) // [
       gain_album=param->norm-lib1770_stats_get_mean(parent->stats.momentary,
           param->momentary.mean.gate);
+#else // ] [
+      gain_album=param->norm-lib1770_stats_get_mean(tree->stats.momentary,
+          param->momentary.mean.gate);
+#endif // ]
       gain_track=param->norm-lib1770_stats_get_mean(tree->stats.momentary,
           param->momentary.mean.gate);
       gain=gain_album+param->weight.value*(gain_track-gain_album);
+_DWRITELNV("gain1=%1.2f",gain);
     }
     else {
+#if defined (BG_MUXER_PARENT) // [
       gain=param->norm-lib1770_stats_get_mean(parent->stats.momentary,
           param->momentary.mean.gate);
+#else // ] [
+      gain=param->norm-lib1770_stats_get_mean(tree->stats.momentary,
+          param->momentary.mean.gate);
+#endif // ]
+_DWRITELNV("gain2=%1.2f",gain);
     }
 
     volume=LIB1770_DB2Q(gain);
     snprintf(filter,sizeof filter,"volume=%1.2f",volume);
+fprintf(stderr,"filter:\"%s\"\n",filter);fflush(stderr);
   }
 
-//_DWRITELNV("\"%" PBU_PRIs "\"",tree->source.path);
-//_DWRITELNV("\"%s\"",filter);
+#if 0 // [
+_DWRITELNV("\"%" PBU_PRIs "\"",tree->source.path);
+_DWRITELNV("filter=\"%s\"",filter);
+#else // ] [
+//fprintf(stderr,"filter:\"%s\"\n",filter);fflush(stderr);
+#endif // ]
+
   ///////////////////////////////////////////////////////////////////////////
   if (ff_muxer_create(&muxer,&track->input,&output,apply?filter:NULL)<0) {
     _DMESSAGE("creating muxer");
