@@ -174,7 +174,7 @@ static int bg_process_muxer_track_annotation_create(bg_tree_t *tree)
       goto e_input;
     }
 #else // ] [
-    if (ff_input_open_muxer(&track->input)<0) {
+    if (ff_input_open_muxer(&tree->track.input)<0) {
       _DMESSAGE("re-opening input");
       goto e_input;
     }
