@@ -390,9 +390,20 @@ static int ff_input_flac_hack(ff_inout_t *in, int transcode,
     int64_t begin, int64_t duration, ff_param_decode_t *d)
 {
   AVCodecParameters *codecpar=in->fmt.ctx->streams[in->ai]->codecpar;
+#if 1 // [
   int hack=AV_CODEC_ID_FLAC==codecpar->codec_id   // FLAC stream
       &&!transcode                                // not transcoding anyway
       &&(0ll<begin||0ll<duration);                // partial stream
+#else // ] [
+  int hack=1;
+	hack=hack&&AV_CODEC_ID_FLAC==codecpar->codec_id;  // FLAC stream
+fprintf(stderr,"(%s,%d,%s) codec_id=%d,AV_CODEC_ID_FLAC=%d\n",pbu_basename(__FILE__),__LINE__,__func__,codecpar->codec_id,AV_CODEC_ID_FLAC);fflush(stderr);
+fprintf(stderr,"(%s,%d,%s) hack=%d\n",pbu_basename(__FILE__),__LINE__,__func__,hack);fflush(stderr);
+  hack=hack&&!transcode;                               // not transcoding anyway
+fprintf(stderr,"(%s,%d,%s) hack=%d\n",pbu_basename(__FILE__),__LINE__,__func__,hack);fflush(stderr);
+  hack=hack&&(0ll<begin||0ll<duration);                // partial stream
+fprintf(stderr,"(%s,%d,%s) hack=%d\n",pbu_basename(__FILE__),__LINE__,__func__,hack);fflush(stderr);
+#endif // ]
 
   if (hack&&d)
     d->request.sample_fmt=codecpar->format;
@@ -773,7 +784,9 @@ static int ff_output_add_astream(ff_inout_t *out)
 
     codecpar->codec_id=ocb&&ocb->codec_id
         ?ocb->codec_id(odata,out->fmt.ctx->oformat):AV_CODEC_ID_FLAC;
+#if defined (FF_FLAC_HACK) // [
     codecpar->format=sample_fmt;
+#endif // ]
 
 #if defined (FF_CHANNEL_LAYOUT_DEPRECATED) // [
 	#error not implemented yet.
@@ -828,8 +841,8 @@ int ff_output_create(ff_inout_t *out, ff_output_callback_t *ocb, void *odata)
   const char *path=ocb&&ocb->path?ocb->path(odata):"";
   const ff_analyzer_t *a=ocb&&ocb->analyzer?ocb->analyzer(odata):NULL;
 #if ! defined (FF_FLAC_HACK) // [
-  enum AVSampleFormat sample_fmt
-      =ocb&&ocb->sample_fmt?ocb->sample_fmt(odata):AV_SAMPLE_FMT_NONE;
+//  enum AVSampleFormat sample_fmt
+//      =ocb&&ocb->sample_fmt?ocb->sample_fmt(odata):AV_SAMPLE_FMT_NONE;
 #endif // ]
   ff_inout_t *in=a->in;
 #if defined (FF_STREAM_METADATA) // [
